@@ -370,10 +370,11 @@ void MainWindow::help()
 void MainWindow::setPosition()
 {
     QPoint pos = QCursor::pos();
-    if (pos.y() + this->size().height() > QGuiApplication::primaryScreen()->geometry().height())
-        pos.setY(QGuiApplication::primaryScreen()->geometry().height() - this->size().height());
-    if (pos.x() + this->size().width() > QGuiApplication::primaryScreen()->geometry().width())
-        pos.setX(QGuiApplication::primaryScreen()->geometry().width() - this->size().width());
+    QScreen *screen = QGuiApplication::screenAt(pos);
+    if (pos.y() + this->size().height() > screen->availableVirtualGeometry().height())
+        pos.setY(screen->availableVirtualGeometry().height() - this->size().height());
+    if (pos.x() + this->size().width() > screen->availableVirtualGeometry().width())
+        pos.setX(screen->availableVirtualGeometry().width() - this->size().width());
     this->move(pos);
 }
 
